@@ -75,7 +75,7 @@ def goto(url, size=None, get=None, post=None, compress=True,
     req.add_header('User-agent', user_agent)
     if referer:
         req.add_header('Referer', url_fix(referer))
-    cookies = cj_from(cookies)
+    cookies = cj_from(cookies, req)
     handlers = [urllib2.HTTPCookieProcessor(cookies)]
     if compress:
         if size:
