@@ -78,7 +78,7 @@ def cj_from_dump(dump, dumper='json'):
     cj._cookies = extras.pickle.loads(dump)
     return cj
 
-def cj_from_dict(cls, cookies_dict):
+def cj_from_dict(cookies_dict, req):
     cj = CookieJar()
     for name, value in cookies_dict.iteritems():
         cookie = Cookie(
@@ -103,13 +103,13 @@ def cj_from_dict(cls, cookies_dict):
         cj.set_cookie(cookie)
     return cj
 
-def cj_from(cookies):
+def cj_from(cookies, req):
     if isinstance(cookies, CookieJar):
         return cookies
     if cookies is None:
         return CookieJar()
     if isinstance(cookies, dict):
-        return cj_from_dict(cookies)
+        return cj_from_dict(cookies, req)
     if isinstance(cookies, basestring):
         return cj_from_dump(cookies)
     assert False, 'cookies must be StringCookieJar, dict or basestring type'
